@@ -3,8 +3,8 @@
 #' It converts a SCOPUS, Clarivate Analytics WoS, Dimensions, Lens.org, PubMed and COCHRANE Database export files or pubmedR and dimensionsR JSON/XML 
 #' objects into a data frame, with cases corresponding to articles and variables to Field Tags as used in WoS.
 #'
-#' @param file a character array containing a sequence of filenames coming from WoS, Scopus, Dimensions, Lens.org, and Pubmed. Alternatively, \code{file} can be 
-#' an object resulting from an API query fetched from Dimensions, PubMed or OpenAlex databases: 
+#' @param file a character array containing a sequence of filenames coming from WoS, Scopus, Dimensions, Lens.org, OpenAlex and Pubmed. Alternatively, \code{file} can be 
+#' an object resulting from an API query fetched from Dimensions, and PubMed databases: 
 #' \tabular{lll}{
 #' a)\tab 'wos' \tab Clarivate Analytics WoS (in plaintext '.txt', Endnote Desktop '.ciw', or bibtex formats '.bib');\cr
 #' b)\tab 'scopus' \tab SCOPUS (exclusively in bibtex format '.bib');\cr
@@ -13,7 +13,7 @@
 #' e)\tab 'pubmed' \tab an object of the class \code{pubmedR (package pubmedR)} containing a collection obtained from a query performed with pubmedR package;\cr
 #' f)\tab 'dimensions' \tab an object of the class \code{dimensionsR (package dimensionsR)} containing a collection obtained from a query performed with dimensionsR package;\cr
 #' g)\tab 'openalex' \tab OpenAlex .csv file;\cr
-#' h)\tab 'openalex_api' \tab a data frame object returned by openalexR package, containing a collection of works resulting from a query fetched from OpenAlex database.}
+#' h)\tab 'openalex_api' \tab the filename and path to a list object returned by openalexR package, containing a collection of works resulting from a query fetched from OpenAlex database.}
 #' @param dbsource is a character indicating the bibliographic database. \code{dbsource} can be \code{dbsource = c('cochrane','dimensions','generic','isi','openalex', 'pubmed','scopus','wos', 'lens')} . Default is \code{dbsource = "isi"}.
 #' @param format is a character indicating the SCOPUS, Clarivate Analytics WoS, and other databases export file format. \code{format} can be \code{c('api', 'bibtex', 'csv', 'endnote','excel','plaintext', 'pubmed')}. Default is \code{format = "plaintext"}.
 #' @param remove.duplicates is logical. If TRUE, the function will remove duplicated items checking by DOI and database ID.
@@ -147,11 +147,12 @@ convert2df<-function(file,dbsource="wos",format="plaintext", remove.duplicates=T
       M <- csvOA2df(file)
     },
     openalex_api = {
-      if (!"bibliometrixDB" %in% class(file)){
-        M <- openalexR::oa2bibliometrix(file)
-      } else {
-        M <- file
-      }
+      M <- apiOA2df(file)
+# if (!"bibliometrixDB" %in% class(file)) {
+#   M <- openalexR::oa2bibliometrix(file)
+# } else {
+#   M <- file
+# }
     }
   )
   if ("PY" %in% names(M)){M$PY=as.numeric(M$PY)} else {M$PY <- NA}
@@ -167,7 +168,7 @@ convert2df<-function(file,dbsource="wos",format="plaintext", remove.duplicates=T
     M$CR <- trim.leading(trimES(gsub("\\[,||\\[||\\]|| \\.\\. || \\. ","",M$CR)))  # remove foreign characters from CR (i.e. Chinese, Russian characters)
   }
   
-  if (dbsource!="cochrane"){M$AU <- gsub(intToUtf8(8217),intToUtf8(39),M$AU)}
+  if (dbsource %in% c("cochrane","openalex_api")){M$AU <- gsub(intToUtf8(8217),intToUtf8(39),M$AU)}
   
   cat("Done!\n\n")
   
